require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xsystemrestorepoint',
  dscmeta_resource_friendly_name: 'xSystemRestorePoint',
  dscmeta_resource_name: 'xSystemRestorePoint',
  dscmeta_module_name: 'xWindowsRestore',
  dscmeta_module_version: '1.0.0',
  docs: 'The DSC xSystemRestorePoint resource type.
         Automatically generated from version 1.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_description: {
      type: 'String',
      desc: 'Specifies a descriptive name for the restore point.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restorepointtype: {
      type: "Optional[Enum['APPLICATION_INSTALL', 'APPLICATION_UNINSTALL', 'DEVICE_DRIVER_INSTALL', 'MODIFY_SETTINGS', 'CANCELLED_OPERATION']]",
      desc: 'Specifies the type of restore point. The default is APPLICATION_INSTALL.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Indicates if the specified restore point created. Set this property to 'Absent' to ensure that the restore point does not exist. Set it to 'Present' to ensure that the restore point does exist. The default is 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
